/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.geoviewer;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import javax.media.jai.PropertyChangeEmitter;
import nl.cloudfarming.client.model.DataProvider;

/**
 * A map consists of one or more layers.
 * 
 *
 * @author Timon Veenstra
 */
public interface Layer extends PropertyChangeEmitter,Transferable{

    //
    // data flavor for drag and drop support of layers
    //
    public static final DataFlavor DATA_FLAVOR = new DataFlavor(Layer.class, "layer");

    /**
     *
     *
     * @return the category of the layer
     */
    public Category getCategory();

    /**
     * The name of the layer.
     *
     * @return String name
     */
    public String getName() ;

    /**
     * A palette contains information about how the layer should be displayed.
     *
     * @return Palette
     */
    public Palette getPalette();
    void setPalette(Palette palette);

    /**
     * Get an array with actions for the layer.
     *
     * @return
     */
    public LayerAction[] getActions();

    /**
     * Returns true if the layer is interactive.
     * Interactive layers contains objects the user can interact (select, edit etc) with.
     * 
     * TODO might be more useful to make this deprecated and determine interactivity based on layer type
     *
     * @return
     */
    public boolean isInterActive();


    /**
     * Returns the dataProvider asociated with this layer.
     * A dataprovider contains an explorerManager with the hierarchical representation of layer objects.
     *
     * @return
     */
    DataProvider getDataProvider();
}
