/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.geoviewer;

/**
 * defines a value range
 *
 * for example a range with all whole numbers between 0 and 10 is defined as:
 * min value = 0
 * max value = 10
 * steps = 10
 *
 * Ranges can have all numeric datatypes.
 *
 * @author Timon Veenstra
 */
public interface ValueRange<D extends Number> {

    /**
     * minimum range value
     * 
     * @return minimum range value
     */
    D getMinValue();

    /**
     * maximum range value
     *
     * @return maximum range value
     */
    D getMaxValue();

    /**
     * amount of steps the range is divided in
     *
     * @return int with amount of steps
     */
    int getSteps();


}
